//
// JWhich - find out which classpath entry a class is loaded from
// (c) 2002 Arno Haase - www.haase-consulting.com
// Software is provided "as is" - no warranty whatsoever is granted
// Permission to copy, use and extend the software is granted provided this
// notice remains part of the software
//

package com.haaseconsulting.jwhich;

import java.io.IOException;

abstract class ClassPathEntry {

    public static ClassPathEntry createEntry (String entry) {
        return isArchive (entry) ?
                (ClassPathEntry) new JarCpEntry (entry) :
                new DirCpEntry (entry);
    }

    private static boolean isArchive (String entry) {
        return entry.toLowerCase ().endsWith (".jar") ||
                entry.toLowerCase ().endsWith (".zip");
    }

    public final boolean hasClass (String fullyQualifiedName) throws IOException {
        return hasFile (asClassFileName (fullyQualifiedName));
    }

    private String asClassFileName (String className) {
        return className.replace ('.', '/') + ".class";
    }

    protected abstract boolean hasFile (String filename) throws IOException;
    public abstract String getPath ();
}
