//
// JWhich - find out which classpath entry a class is loaded from
// (c) 2002 Arno Haase - www.haase-consulting.com
// Software is provided "as is" - no warranty whatsoever is granted
// Permission to copy, use and extend the software is granted provided this
// notice remains part of the software
//

package com.haaseconsulting.jwhich;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.StringTokenizer;

public class JWhich {

    public static void main (String[] args) {
        if (args.length != 1) {
            printUsage ();
            System.exit (0);
        }

        final ClassPathEntry[] classPath = readClassPath();

        for (int i=0; i<classPath.length; i++) {
            try {
                if (classPath[i].hasClass(args[0])) {
                    System.out.println (classPath[i].getPath());
                }
            }
            catch (IOException e) {
                System.out.println ("*[" + classPath[i].getPath() + "]");
            }
        }
    }


    private static void printUsage () {
        System.out.println ("JWhich - find out which classpath entry a class is loaded from");
        System.out.println ("  (c) 2002 Arno Haase - www.haase-consulting.com");
        System.out.println ("  Software is provided \"as is\" - no warranty whatsoever is granted");
        System.out.println ("");
        System.out.println ("Usage:");
        System.out.println ("  jwhich <fully qualified class name>");
        System.out.println ("");
        System.out.println ("Output:");
        System.out.println ("  '<classpath entry>'   : means that the class was found there");
        System.out.println ("  '*[<classpath entry>]': means that the classpath entry is invalid");
    }


    private static ClassPathEntry[] readClassPath () {
        final Collection pathItems = new ArrayList ();

        final String classPath = System.getProperty ("java.class.path");
        final String separator = System.getProperty ("path.separator");
        final StringTokenizer st = new StringTokenizer (classPath, separator);

        while (st.hasMoreTokens ()) {
            pathItems.add (ClassPathEntry.createEntry (st.nextToken ().toString ()));
        }

        return (ClassPathEntry[]) pathItems.toArray (new ClassPathEntry[0]);
    }

}
